:orphan:



.. _sphx_glr_documentation_auto_examples_hr:

============================================
Example: Hubness reduction
============================================

These examples show how to perform hubness reduction in kNN classification
in (nested) cross-validation and pipelines.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Estimators from scikit-hubness can - of course - be used in a scikit-learn Pipeline. In this ex...">

.. only:: html

    .. figure:: /documentation/auto_examples_hr/images/thumb/sphx_glr_pipelines_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_hr_pipelines.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples_hr/pipelines

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This dataset contains a set of face images taken between April 1992 and April 1994 at AT&amp;T Labo...">

.. only:: html

    .. figure:: /documentation/auto_examples_hr/images/thumb/sphx_glr_olivetti_faces_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_hr_olivetti_faces.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples_hr/olivetti_faces
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_hr_python.zip <//home/user/feldbauer/PycharmProjects/hubness/docs/documentation/auto_examples_hr/auto_examples_hr_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_hr_jupyter.zip <//home/user/feldbauer/PycharmProjects/hubness/docs/documentation/auto_examples_hr/auto_examples_hr_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
